# Changelog

Release history for `hordelib`.

## v0.0.3 - 2023-04-02

### Added
- Adds initial basic support for horde text to image payloads.

### Fixed
- Correctly updates embedded ComfyUI dependency when required.

## v0.0.2 - 2023-04-02

### Added
- Adds stable diffusion hires fix pipeline.
- Workflow and code to load ComfyUI pipelines saved from the web UI.

## v0.0.1 - 2023-03-31

### Added
- Initial proof of concept.
